# Examples

This section contains Jupyter Notebooks with narrative workflows using the
`coincident` library.

````{grid} 3
:class-container: text-center
:gutter: 3

```{grid-item-card}
:link: quickstart
:link-type: doc
:class-header: bg-light
**Quickstart!** 🚀
^^^
Basic search functionality
```

```{grid-item-card}
:link: cascading_search
:link-type: doc
:class-header: bg-light
**Cascading Search**
^^^
Search for multiple intersecting datasets in one go
```

```{grid-item-card}
:link: sliderule
:link-type: doc
:class-header: bg-light
**Sliderule Data I/O**
^^^
Use sliderule service to load altimeter data and sample DEMs
```

```{grid-item-card}
:link: contextual_data
:link-type: doc
:class-header: bg-light
**Contextual Data**
^^^
Load and plot landcover and global elevation data for an area of interest
```

```{grid-item-card}
:link: additional_lidar
:link-type: doc
:class-header: bg-light
**Additional LiDAR Catalogs**
^^^
Search for NOAA Coastal, NCALM and NEON LiDAR datasets
```

```{grid-item-card}
:link: elevation_plotting
:link-type: doc
:class-header: bg-light
**Comparing elevation measurements**
^^^
Create standardized panel and boxplot figure comparing multiple DEM and altimeter measurements
```

````

```{toctree}
:hidden:

quickstart
cascading_search
sliderule
contextual_data
additional_lidar
elevation_plotting
```
